==> owncloud-10.0.7.tgz: owncloud/lib/l10n/gl.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Non é posíbel escribir no directorio «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Polo xeral, isto pode ser fixado para permitirlle ao servidor web acceso de escritura  ao directorio «config»",
    "See %s" : "Vexa %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «config»%s.",
    "Sample configuration detected" : "Detectouse a configuración de exemplo",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectouse que foi copiada a configuración de exemplo. Isto pode rachar a súa instalación e non é compatíbel. Lea a documentación antes de facer cambios en config.php",
    "PHP %s or higher is required." : "Requirese PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "Requírese PHP cunha versión inferior a %s.",
    "Following databases are supported: %s" : "Admítense as seguintes bases de datos: %s",
    "The command line tool %s could not be found" : "Non foi posíbel atopar a ferramenta de liña de ordes %s",
    "The library %s is not available." : "Non está dispoñíbel a biblioteca %s.",
    "Library %s with a version higher than %s is required - available version %s." : "Requírese a biblioteca %s cunha versión superior a %s - dispoñíbel a versión %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Requírese a biblioteca %s cunha versión inferior a %s - dispoñíbel a versión %s.",
    "Following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
    "ownCloud %s or higher is required." : "Requírese ownCloud %s ou superior.",
    "ownCloud %s or lower is required." : "Requírese ownCloud %s ou inferior.",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "Invalid image" : "Imaxe incorrecta",
    "today" : "hoxe",
    "yesterday" : "onte",
    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n días"],
    "last month" : "último mes",
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "last year" : "último ano",
    "_%n year ago_::_%n years ago_" : ["hai %n ano","hai %n anos"],
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
    "seconds ago" : "segundos atrás",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte co administrador.",
    "None" : "Ningún",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
    "4-byte characters are not supported in file names" : "Non se admiten os caracteres de 4 bytes nos nomes de ficheiro",
    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
    "File name is too long" : "O nome de ficheiro é longo de máis",
    "App directory already exists" : "Xa existe o directorio da aplicación",
    "Can't create app folder. Please fix permissions. %s" : "Non é posíbel crear o cartafol de aplicacións. Corrixa os permisos. %s",
    "No source specified when installing app" : "Non foi especificada ningunha orixe ao instalar a aplicación",
    "No href specified when installing app from http" : "Non foi especificada ningunha «href» ao instalar a aplicación",
    "No path specified when installing app from local file" : "Non foi especificada ningunha ruta ao instalar a aplicación desde un ficheiro local",
    "Archives of type %s are not supported" : "Os arquivos do tipo %s non están admitidos",
    "Failed to open archive when installing app" : "Non foi posíbel abrir o arquivo ao instalar aplicacións",
    "App does not provide an info.xml file" : "A aplicación non fornece un ficheiro info.xml",
    "App can't be installed because of not allowed code in the App" : "Non é posíbel instalar a aplicación por mor de conter código non permitido",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Non é posíbel instalar a aplicación por non seren compatíbel  con esta versión do ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Non é posíbel instalar a aplicación por conter a etiqueta <shipped>true</shipped> que non está permitida para as aplicacións non enviadas",
    "Apps" : "Aplicacións",
    "General" : "Xeral",
    "Storage" : "Almacenamento",
    "Security" : "Seguridade",
    "Encryption" : "Cifrado",
    "Sharing" : "Compartindo",
    "Search" : "Buscar",
    "Updates" : "Actualizacións",
    "%s enter the database username." : "%s introduza o nome de usuario da base de datos",
    "%s enter the database name." : "%s introduza o nome da base de datos",
    "%s you may not use dots in the database name" : "%s non se poden empregar puntos na base de datos",
    "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
    "DB Error: \"%s\"" : "Produciuse un erro na base de datos: «%s»",
    "Offending command was: \"%s\"" : "A orde infractora foi: «%s»",
    "You need to enter either an existing account or the administrator." : "Deberá introducir unha conta existente ou o administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "A orde infractora foi: «%s», nome: %s, contrasinal: %s",
    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun entorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
    "Set an admin username." : "Estabeleza un nome de usuario administrador",
    "Set an admin password." : "Estabeleza un contrasinal de administrador",
    "Can't create or write into the data directory %s" : "Non é posíbel crear ou escribir o directorio «data» %s",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "%s shared »%s« with you" : "%s compartiu «%s» con vostede",
    "%s via %s" : "%s vía %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %i",
    "Sharing %s failed, because the file does not exist" : "Fallou a compartición de %s, o ficheiro non existe",
    "You are not allowed to share %s" : "Non ten permiso para compartir %s",
    "Sharing %s failed, because the user %s does not exist" : "Fallou a compartición de %s, o usuario %s non existe",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Fallou a compartición de %s, o usuario %s non é membro de ningún grupo que sexa membro de %s",
    "Sharing %s failed, because this item is already shared with %s" : "Fallou a compartición de %s, este elemento xa está compartido con %s",
    "Sharing %s failed, because the group %s does not exist" : "Fallou a compartición de %s, o grupo %s non existe",
    "Sharing %s failed, because %s is not a member of the group %s" : "Fallou a compartición de %s, %s non é membro do grupo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Ten que fornecer un contrasinal para a ligazón pública, só se permiten ligazóns protexidas",
    "Sharing %s failed, because sharing with links is not allowed" : "Fallou a compartición de %s, non está permitido compartir con ligazóns",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Fallou a compartición de %s, non foi posíbel atopar %s,é probábel que o servidor non estea accesíbel.",
    "Share type %s is not valid for %s" : "Non se admite a compartición do tipo %s para %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Non é posíbel estabelecer permisos para %s, os permisos superan os permisos concedidos a %s",
    "Setting permissions for %s failed, because the item was not found" : "Non é posíbel estabelecer permisos para %s, non se atopa o elemento",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Non é posíbel estabelecer a data de caducidade. As comparticións non poden caducar máis aló de %s após de seren compartidas",
    "Cannot set expiration date. Expiration date is in the past" : "Non é posíbel estabelecer a data de caducidade. A data de caducidade está no pasado.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Non é posíbel limpar a data de caducidade. É necesaria algunha compartición para ter unha data de caducidade.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
    "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Fallou a compartición de %s, os permisos superan os permisos concedidos a %s",
    "Sharing %s failed, because resharing is not allowed" : "Fallou a compartición de %s, non está permitido repetir a compartción",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Fallou a compartición de %s, a infraestrutura de compartición para %s non foi quen de atopar a orixe",
    "Sharing %s failed, because the file could not be found in the file cache" : "Fallou a compartición de %s, non foi posíbel atopar o ficheiro na caché de ficheiros",
    "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
    "A valid username must be provided" : "Debe fornecer un nome de usuario",
    "A valid password must be provided" : "Debe fornecer un contrasinal",
    "The username is already being used" : "Este nome de usuario xa está a ser usado",
    "Help" : "Axuda",
    "Settings" : "Axustes",
    "Users" : "Usuarios",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Non é posíbel instalar a aplicación «%s» por mor de non cumprirse as dependencias: %s",
    "web services under your control" : "servizos web baixo o seu control",
    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, tenteo máis tarde.",
    "Can't read file" : "Non é posíbel ler o ficheiro",
    "Application is not enabled" : "A aplicación non está activada",
    "Authentication error" : "Produciuse un erro de autenticación",
    "Token expired. Please reload page." : "Testemuña caducada. Recargue a páxina.",
    "Unknown user" : "Usuario descoñecido",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Non hay controladores de base de datos (sqlite, mysql, ou postgresql) instalados.",
    "Cannot write into \"config\" directory" : "Non é posíbel escribir no directorio «config»",
    "Cannot write into \"apps\" directory" : "Non é posíbel escribir no directorio «apps»",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «apps»%s ou a desactivación da «appstore» no ficheiro de configuración.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «root»%s.",
    "Setting locale to %s failed" : "Fallou o axuste da configuración local a %s",
    "Please install one of these locales on your system and restart your webserver." : "Instale unha destas configuracións locais no seu sistema e reinicie o servidor web.",
    "Please ask your server administrator to install the module." : "Pregúntelle ao administrador do servidor pola instalación do módulo.",
    "PHP module %s not installed." : "O módulo PHP %s non está instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Facer este axuste en php.ini fará que ownCloud volva executarse",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está estabelecido a «%s» no canto do valor «0» agardado",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para arranxar este problema, estabeleza <code>mbstring.func_overload</code> a <code>0</code> no ficheiro php.ini",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varias aplicacións sexan inaccesíbeis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
    "Please ask your server administrator to restart the web server." : "Pregúntelle ao administrador do servidor polo reinicio do servidor web..",
    "PostgreSQL >= 9 required" : "Requírese PostgreSQL >= 9",
    "Please upgrade your database version" : "Anove a versión da súa base de datos",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida seren listado por outros usuarios.",
    "Check the value of \"datadirectory\" in your configuration" : "Comprobe o valor de «datadirectory» na configuración",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Comprobe que o directorio de datos conten un ficheiro «.ocdata» na súa raíz.",
    "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s»."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/gl.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Non é posíbel escribir no directorio «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Polo xeral, isto pode ser fixado para permitirlle ao servidor web acceso de escritura  ao directorio «config»",
    "See %s" : "Vexa %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «config»%s.",
    "Sample configuration detected" : "Detectouse a configuración de exemplo",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectouse que foi copiada a configuración de exemplo. Isto pode rachar a súa instalación e non é compatíbel. Lea a documentación antes de facer cambios en config.php",
    "PHP %s or higher is required." : "Requirese PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "Requírese PHP cunha versión inferior a %s.",
    "Following databases are supported: %s" : "Admítense as seguintes bases de datos: %s",
    "The command line tool %s could not be found" : "Non foi posíbel atopar a ferramenta de liña de ordes %s",
    "The library %s is not available." : "Non está dispoñíbel a biblioteca %s.",
    "Library %s with a version higher than %s is required - available version %s." : "Requírese a biblioteca %s cunha versión superior a %s - dispoñíbel a versión %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Requírese a biblioteca %s cunha versión inferior a %s - dispoñíbel a versión %s.",
    "Following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
    "ownCloud %s or higher is required." : "Requírese ownCloud %s ou superior.",
    "ownCloud %s or lower is required." : "Requírese ownCloud %s ou inferior.",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "Invalid image" : "Imaxe incorrecta",
    "today" : "hoxe",
    "yesterday" : "onte",
    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n días"],
    "last month" : "último mes",
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "last year" : "último ano",
    "_%n year ago_::_%n years ago_" : ["hai %n ano","hai %n anos"],
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n horas"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
    "seconds ago" : "segundos atrás",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte co administrador.",
    "None" : "Ningún",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
    "4-byte characters are not supported in file names" : "Non se admiten os caracteres de 4 bytes nos nomes de ficheiro",
    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
    "File name is too long" : "O nome de ficheiro é longo de máis",
    "App directory already exists" : "Xa existe o directorio da aplicación",
    "Can't create app folder. Please fix permissions. %s" : "Non é posíbel crear o cartafol de aplicacións. Corrixa os permisos. %s",
    "No source specified when installing app" : "Non foi especificada ningunha orixe ao instalar a aplicación",
    "No href specified when installing app from http" : "Non foi especificada ningunha «href» ao instalar a aplicación",
    "No path specified when installing app from local file" : "Non foi especificada ningunha ruta ao instalar a aplicación desde un ficheiro local",
    "Archives of type %s are not supported" : "Os arquivos do tipo %s non están admitidos",
    "Failed to open archive when installing app" : "Non foi posíbel abrir o arquivo ao instalar aplicacións",
    "App does not provide an info.xml file" : "A aplicación non fornece un ficheiro info.xml",
    "App can't be installed because of not allowed code in the App" : "Non é posíbel instalar a aplicación por mor de conter código non permitido",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Non é posíbel instalar a aplicación por non seren compatíbel  con esta versión do ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Non é posíbel instalar a aplicación por conter a etiqueta <shipped>true</shipped> que non está permitida para as aplicacións non enviadas",
    "Apps" : "Aplicacións",
    "General" : "Xeral",
    "Storage" : "Almacenamento",
    "Security" : "Seguridade",
    "Encryption" : "Cifrado",
    "Sharing" : "Compartindo",
    "Search" : "Buscar",
    "Updates" : "Actualizacións",
    "%s enter the database username." : "%s introduza o nome de usuario da base de datos",
    "%s enter the database name." : "%s introduza o nome da base de datos",
    "%s you may not use dots in the database name" : "%s non se poden empregar puntos na base de datos",
    "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
    "DB Error: \"%s\"" : "Produciuse un erro na base de datos: «%s»",
    "Offending command was: \"%s\"" : "A orde infractora foi: «%s»",
    "You need to enter either an existing account or the administrator." : "Deberá introducir unha conta existente ou o administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "A orde infractora foi: «%s», nome: %s, contrasinal: %s",
    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun entorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
    "Set an admin username." : "Estabeleza un nome de usuario administrador",
    "Set an admin password." : "Estabeleza un contrasinal de administrador",
    "Can't create or write into the data directory %s" : "Non é posíbel crear ou escribir o directorio «data» %s",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "%s shared »%s« with you" : "%s compartiu «%s» con vostede",
    "%s via %s" : "%s vía %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %i",
    "Sharing %s failed, because the file does not exist" : "Fallou a compartición de %s, o ficheiro non existe",
    "You are not allowed to share %s" : "Non ten permiso para compartir %s",
    "Sharing %s failed, because the user %s does not exist" : "Fallou a compartición de %s, o usuario %s non existe",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Fallou a compartición de %s, o usuario %s non é membro de ningún grupo que sexa membro de %s",
    "Sharing %s failed, because this item is already shared with %s" : "Fallou a compartición de %s, este elemento xa está compartido con %s",
    "Sharing %s failed, because the group %s does not exist" : "Fallou a compartición de %s, o grupo %s non existe",
    "Sharing %s failed, because %s is not a member of the group %s" : "Fallou a compartición de %s, %s non é membro do grupo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Ten que fornecer un contrasinal para a ligazón pública, só se permiten ligazóns protexidas",
    "Sharing %s failed, because sharing with links is not allowed" : "Fallou a compartición de %s, non está permitido compartir con ligazóns",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Fallou a compartición de %s, non foi posíbel atopar %s,é probábel que o servidor non estea accesíbel.",
    "Share type %s is not valid for %s" : "Non se admite a compartición do tipo %s para %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Non é posíbel estabelecer permisos para %s, os permisos superan os permisos concedidos a %s",
    "Setting permissions for %s failed, because the item was not found" : "Non é posíbel estabelecer permisos para %s, non se atopa o elemento",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Non é posíbel estabelecer a data de caducidade. As comparticións non poden caducar máis aló de %s após de seren compartidas",
    "Cannot set expiration date. Expiration date is in the past" : "Non é posíbel estabelecer a data de caducidade. A data de caducidade está no pasado.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Non é posíbel limpar a data de caducidade. É necesaria algunha compartición para ter unha data de caducidade.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
    "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Fallou a compartición de %s, os permisos superan os permisos concedidos a %s",
    "Sharing %s failed, because resharing is not allowed" : "Fallou a compartición de %s, non está permitido repetir a compartción",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Fallou a compartición de %s, a infraestrutura de compartición para %s non foi quen de atopar a orixe",
    "Sharing %s failed, because the file could not be found in the file cache" : "Fallou a compartición de %s, non foi posíbel atopar o ficheiro na caché de ficheiros",
    "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
    "A valid username must be provided" : "Debe fornecer un nome de usuario",
    "A valid password must be provided" : "Debe fornecer un contrasinal",
    "The username is already being used" : "Este nome de usuario xa está a ser usado",
    "Help" : "Axuda",
    "Settings" : "Axustes",
    "Users" : "Usuarios",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Non é posíbel instalar a aplicación «%s» por mor de non cumprirse as dependencias: %s",
    "web services under your control" : "servizos web baixo o seu control",
    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, tenteo máis tarde.",
    "Can't read file" : "Non é posíbel ler o ficheiro",
    "Application is not enabled" : "A aplicación non está activada",
    "Authentication error" : "Produciuse un erro de autenticación",
    "Token expired. Please reload page." : "Testemuña caducada. Recargue a páxina.",
    "Unknown user" : "Usuario descoñecido",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Non hay controladores de base de datos (sqlite, mysql, ou postgresql) instalados.",
    "Cannot write into \"config\" directory" : "Non é posíbel escribir no directorio «config»",
    "Cannot write into \"apps\" directory" : "Non é posíbel escribir no directorio «apps»",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «apps»%s ou a desactivación da «appstore» no ficheiro de configuración.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Polo xeral, isto pode ser fixado para %spermitirlle ao servidor web acceso de escritura  ao directorio «root»%s.",
    "Setting locale to %s failed" : "Fallou o axuste da configuración local a %s",
    "Please install one of these locales on your system and restart your webserver." : "Instale unha destas configuracións locais no seu sistema e reinicie o servidor web.",
    "Please ask your server administrator to install the module." : "Pregúntelle ao administrador do servidor pola instalación do módulo.",
    "PHP module %s not installed." : "O módulo PHP %s non está instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Facer este axuste en php.ini fará que ownCloud volva executarse",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está estabelecido a «%s» no canto do valor «0» agardado",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para arranxar este problema, estabeleza <code>mbstring.func_overload</code> a <code>0</code> no ficheiro php.ini",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varias aplicacións sexan inaccesíbeis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
    "Please ask your server administrator to restart the web server." : "Pregúntelle ao administrador do servidor polo reinicio do servidor web..",
    "PostgreSQL >= 9 required" : "Requírese PostgreSQL >= 9",
    "Please upgrade your database version" : "Anove a versión da súa base de datos",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida seren listado por outros usuarios.",
    "Check the value of \"datadirectory\" in your configuration" : "Comprobe o valor de «datadirectory» na configuración",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Comprobe que o directorio de datos conten un ficheiro «.ocdata» na súa raíz.",
    "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s».",
    "Imprint" : "Impresión",
    "__language_name__" : "Galego"
},
"nplurals=2; plural=(n != 1);");
